@@ -1,7 +1,8 @@
 #!/bin/sh
-V=4.1.1
+V="4.2.0"
 prefix=/usr
 infodir=${prefix}/share/info
+docdir=${prefix}/share/doc
 
 # Install the .info files
 cd ${infodir}
@@ -12,7 +13,7 @@ done
 # Install default zprofile if needed
 if [ ! -f /etc/zprofile ]; then
   echo "Installing default /etc/zprofile"
-  install -c -m 755 /usr/doc/zsh-$V/StartupFiles/zprofile /etc/zprofile
+  install -c -m 755 ${docdir}/zsh-$V/StartupFiles/zprofile /etc/zprofile
 else
   echo "Keeping current /etc/zprofile"
 fi
